﻿using System.Drawing;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinExplorerBar;

namespace UltraExplorerBarGroupCheckBox
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();
			ultraExplorerBar1.CreationFilter = new ExplorerBarGroupCreationFilter();
		}
	}

	class ExplorerBarGroupCreationFilter : IUIElementCreationFilter
	{
		#region IUIElementCreationFilter Members

		public void AfterCreateChildElements(UIElement parent)
		{
			if (parent is UltraExplorerBarGroupHeaderUIElement)
			{
				var headerElement = parent as UltraExplorerBarGroupHeaderUIElement;
				var checkElement = new CheckBoxUIElement(parent);
				// Set the checkbox's size and position.
				var headerRect = headerElement.Rect;
				int Y = headerRect.Y + (headerRect.Height / 2) - (checkElement.CheckSize.Height / 2);
				checkElement.Rect = new Rectangle(headerRect.X + 3, Y, checkElement.CheckSize.Width, checkElement.CheckSize.Height);
				// Add the checkbox to the group header.
				headerElement.ChildElements.Insert(0, checkElement);
				// Resize and reposition the header text.
				var element = headerElement.ChildElements[1];
				var rect = element.Rect;
				int amtToAdjustBy = 5;
				rect.Width -= amtToAdjustBy;
				rect.X += amtToAdjustBy;
				element.Rect = rect;
				// Handle any clicks on the checkbox.
				checkElement.ElementClick += new UIElementEventHandler(checkElement_ElementClick);
				// Set the checkbox's checked state to that which was previously stored in the ElementClick event handler.
				var group = checkElement.Parent.GetContext(typeof(UltraExplorerBarGroup)) as UltraExplorerBarGroup;
				if (group.Tag != null)
				{
					checkElement.CheckState = (CheckState)System.Enum.Parse(typeof(CheckState), group.Tag.ToString());
				}
			}
		}

		void checkElement_ElementClick(object sender, UIElementEventArgs e)
		{
			// Get the checkbox that was clicked.
			var checkElement = e.Element as CheckBoxUIElement;
			// Get the group the checkbox is in.
			var group = checkElement.Parent.GetContext(typeof(UltraExplorerBarGroup)) as UltraExplorerBarGroup;
			// Store the checked state of the checkbox in the group's tag.
			group.Tag = checkElement.CheckState;
			// If you wanted to, you could fire an event here so your application could do something when one of the checkboxes is clicked.
		}

		public bool BeforeCreateChildElements(UIElement parent)
		{
			return false;
		}

		#endregion
	}
}
